%global project_owner MapServer
%global project_name tinyows

Name:      tinyows
Version:   1.2.2
Release:   1%{?dist}
Summary:   WFS-T and FE implementation server

License:   MIT
URL:       https://mapserver.org/tinyows/

Source0:   https://github.com/%{project_owner}/%{project_name}/archive/v%{version}/%{project_name}-%{version}.tar.gz

Source1:   no_date_footer.html

Requires:  httpd 

BuildRequires: autoconf
BuildRequires: ctags
BuildRequires: doxygen
BuildRequires: gcc
BuildRequires: indent
BuildRequires: flex
BuildRequires: libfl-static
BuildRequires: libxml2-devel
BuildRequires: postgis
BuildRequires: postgis-client
BuildRequires: postgresql-devel

%ifarch %valgrind_arches
BuildRequires: valgrind-devel
%endif

%description
TinyOWS server implements latest WFS-T standard versions,
as well as related standards such as Filter Encoding (FE).

%package doc
Summary: Documentation files for TinyOWS Server
BuildArch: noarch

%description doc
TinyOWS server implements latest WFS-T standard versions,
as well as related standards such as Filter Encoding (FE).

%prep
%setup -q -n %{name}-%{version}

# clean SVN
find . -type d -name .svn -exec rm -rf '{}' +

# copy no_date_footer.html in
cp %{SOURCE1} .

%build
autoconf
%configure

# fix datadir lookup path
sed -i -e 's|/usr/tinyows/|%{_datadir}/%{name}/|' src/ows_define.h
# fix DSO lookup
sed -i -e 's|-lpq|-lpq -lm|' Makefile

make %{?_smp_mflags}

# disable timestamp inside docs
sed -i -e 's|HTML_FOOTER|HTML_FOOTER=no_date_footer.html\n\#|g' doc/Doxyfile
make doxygen

%install

install -d %{buildroot}%{_bindir}
cp %{_bindir}/shp2pgsql %{buildroot}%{_bindir}/shp2pgsql
install -p -m 0755 tinyows %{buildroot}%{_bindir}/
install -d %{buildroot}%{_datadir}/%{name}
cp -pR schema %{buildroot}%{_datadir}/%{name}/
install -d %{buildroot}%{_sysconfdir}/%{name}
install -p -m 0644 ms4w/apps/tinyows-svn/config.xml %{buildroot}%{_sysconfdir}/%{name}
pushd %{buildroot}%{_datadir}/%{name}/
   ln -s ../../../%{_sysconfdir}/%{name}/config.xml config.xml
popd

%check

# NOTE(neil): 2024-08-25 tests require a postgres database running; unable to run in %check
# https://github.com/MapServer/tinyows/blob/f1dc7bc86fc4d69faddd79ed2804d98c11802ba8/.github/workflows/linux.sh#L19-L22
# make check || true

%files
%defattr(-,root,root,-)
%license LICENSE.md
%doc README.md VERSION.md
%doc doc/doxygen
%{_bindir}/shp2pgsql
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/config.xml

%files doc
%{_datadir}/%{name}

%changelog
* Tue Aug 20 2024 Neil Hanlon <neil@shrug.pw> - 1.2.2-1
- update to 1.2.2 for re-review

* Mon Jun 07 2010 Balint Cristian <cristian.balint@gmail.com> - 0.8.0-1
- new upstream

* Thu Mar 18 2010 Balint Cristian <rezso@rdsor.ro> - 0.7.0-1
- new upstream

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jan 05 2009 Balint Cristian <rezso@rdsor.ro> - 0.6.0-3
- initial import

* Thu Sep 25 2008 Balint Cristian <rezso@rdsor.ro> - 0.6.0-2
- shorter summary description

* Thu Sep 25 2008 Balint Cristian <rezso@rdsor.ro> - 0.6.0-1
- initial package for fedora 
